/* QuestCore Item Generator
 *
 * Version 1.1
 * 9/25/2020
 *
 * Function for generating weapon scripts
 *
 * weapon.c
 */

#include <stdio.h>
#include <string.h>
#include "options.h"
#include "color.h"

void mkweapon()
{
	typedef struct
	{
		char name[32];
		char varname[24];
		char shortname[24];
		char desc[128];
		char projectile[4];
		char ammo[8];
		char max_load[12];
		char action[32];
		char damage[8];
		char stun[4];
		char paralyze[4];
		char value[8];
	} WEAPON_T;

	char w_outfile[64];

	printf("%sFile (default: %s): %s", GREEN, DEFAULT_WEAPON_OUTPUT_FILE, RESET);
	fgets(w_outfile, 64, stdin);
	w_outfile[strcspn(w_outfile, "\n")] = 0;

	if (strlen(w_outfile) == 0) {
		strcpy(w_outfile, DEFAULT_WEAPON_OUTPUT_FILE);
	}

	WEAPON_T Weapon;
	FILE *fptr;
	fptr = fopen(w_outfile, "a");

	printf("Creating new weapon...\nWriting to file %s\n\n", w_outfile);

	printf("%sWeapon Name: %s", GREEN, RESET);
	fgets(Weapon.name, 32, stdin);
	fprintf(fptr, "@create $weapon named %s", Weapon.name);

	printf("%sGlobal Variable Name for #0: %s", GREEN, RESET);
	fgets(Weapon.varname, 24, stdin);
	Weapon.varname[strcspn(Weapon.varname, "\n")] = 0;

	char sn[4] = {Weapon.name[0], Weapon.name[1], Weapon.name[2], '\0'};
	strcpy(Weapon.shortname, sn);

	printf("%sDescription: %s", GREEN, RESET);
	fgets(Weapon.desc, 128, stdin);
	fprintf(fptr, "@desc %s as %s", Weapon.shortname, Weapon.desc);
	
	printf("%sProjectile (0 or 1): %s", GREEN, RESET);
	fgets(Weapon.projectile, 4, stdin);
	fprintf(fptr, "@set %s.shoots to %s", Weapon.shortname, Weapon.projectile);

	if (!strcmp(Weapon.projectile, "1\n")) {
		printf("%sAmmo (#obj): %s", GREEN, RESET);
		fgets(Weapon.ammo, 8, stdin);
		fprintf(fptr, "@set %s.ammo_type to %s", Weapon.shortname, Weapon.ammo);
		printf("%sMaximum Load: %s", GREEN, RESET);
		fgets(Weapon.max_load, 12, stdin);
		fprintf(fptr, "@set %s.max_load to %s", Weapon.shortname, Weapon.max_load);
	}

	printf("%sAction String: %s", GREEN, RESET);
	fgets(Weapon.action, 32, stdin);
	Weapon.action[strcspn(Weapon.action, "\n")] = 0;
	if (!strcmp(Weapon.projectile, "1\n")) {
		fprintf(fptr, "@set %s.shoot_verbage to \" %%<%ss> %%p %%D at \"\n", Weapon.shortname, Weapon.action);
	} else {
		fprintf(fptr, "@set %s.usage_verbage to \" %%<%ss> %%p %%D at \"\n", Weapon.shortname, Weapon.action);
	}

	printf("%sDamage (decimal): %s", GREEN, RESET);
	fgets(Weapon.damage, 8, stdin);
	if (!strcmp(Weapon.projectile, "1\n")) {
		fprintf(fptr, "@set %s.projectile_dam to %s", Weapon.shortname, Weapon.damage);
	} else {
		fprintf(fptr, "@set %s.damage_base to %s", Weapon.shortname, Weapon.damage);	
	}

	printf("%sCan Stun (0 or 1): %s", GREEN, RESET);
	fgets(Weapon.stun, 4, stdin);
	fprintf(fptr, "@set %s.can_stun to %s", Weapon.shortname, Weapon.stun);
	
	printf("%sCan Paralyze (0 or 1): %s", GREEN, RESET);
	fgets(Weapon.paralyze, 4, stdin);
	fprintf(fptr, "@set %s.can_paralyse to %s", Weapon.shortname, Weapon.paralyze);

	printf("%sValue (decimal): %s", GREEN, RESET);
	fgets(Weapon.value, 8, stdin);
	fprintf(fptr, "@set %s.value_base to %s", Weapon.shortname, Weapon.value);

	fprintf(fptr, "@chmod %s rf\n", Weapon.shortname);
	fprintf(fptr, ";add_property(#0, \"%s\", max_object(), {player, \"rc\"})\n", Weapon.varname);
	fprintf(fptr, ";move($%s, $nothing)\n", Weapon.varname);
	fprintf(fptr, "@kgen $%s\n", Weapon.varname);

	fprintf(fptr, "\n");
	fclose(fptr);
	return;
}
